---
id: 20211122195910
title: Markdown documents requirements
tags: [definition, markdown, mkdocs, zettelkasten]
---

# Markdown documents requirements

The source directory with markdown documents (usually named `docs`) must contain `index.md` file like the one you saw [here](index.md). It isn't a true zettel, but rather an index zettel. The theme won't render it as a card with header and footer, because none is expected.
The same applies to another special file called `tags.md`.

Any markdown document representing a zettel must contain a [yaml frontmatter](https://www.mkdocs.org/user-guide/writing-your-docs/#yaml-style-meta-data) with Zettelkasten ID (`id:` key), and optionally a title (`title:` key) and a list of tags (`tags:`).

Example:

```markdown
---
id: 20211122110202
title: Welcome to MkDocs Zettelkasten
tags: [testing, unimportant]

---

# Welcome to MkDocs Zettelkasten

This is a zettel in form of a markdown file.

---
web: [MkDocs Zettelkasten](https://github.com/buvis/mkdocs-zettelkasten)

---
```

The file extension must be `.md` otherwise MkDocs Zettelkasten plugin won't process it.
